@@ -12,7 +12,7 @@ class PlayerPoolSettings(object):
         self.randomize = randomize
 
     def exist(self):
-        return str(self) == 'None'
+        return str(self) != 'None'
 
     # TODO: format this like a proper repr(), i.e. <PlayerPoolSettings: ...>
     def __repr__(self):
